==> chatgpt_plugin-1.0.0.tar.gz: chatgpt_plugin/src/Form/ChatGPTConfigForm.php <==
<?php

namespace Drupal\chatgpt\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Function to create the ChatGPT Config Form.
 */
class ChatGPTConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'chatgpt.adminsettings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'chatgpt_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('chatgpt.adminsettings');

    $form['chatgpt_setting_compare_tool'] = [
      '#type' => 'markup',
      '#markup' => '<a id="chatgpt-tool" href="https://gpttools.com/comparisontool" target="_blank">Click here to access the ChatGPT API setting comparison tool</a>',
    ];

    $form['chatgpt_endpoint'] = [
      '#type' => 'textfield',
      '#title' => $this->t('ChatGPT API Endpoint'),
      '#description' => $this->t('Please provide the ChatGPT Completion API Endpoint here.'),
      '#default_value' => $config->get('chatgpt_endpoint') ? $config->get('chatgpt_endpoint') : 'https://api.openai.com/v1/completions',
    ];

    $form['chatgpt_model'] = [
      '#type' => 'textfield',
      '#title' => $this->t('ChatGPT API Model'),
      '#description' => $this->t('Please provide the ChatGPT API Model here. List of models can be found <a href="https://beta.openai.com/docs/models/gpt-3" target="_blank"><b>Here</b></a>'),
      '#default_value' => $config->get('chatgpt_model'),
    ];

    $form['chatgpt_token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('ChatGPT Access Token'),
      '#description' => $this->t('Please provide the ChatGPT Access Token here.'),
      '#default_value' => $config->get('chatgpt_token'),
    ];

    $form['chatgpt_temperature'] = [
      '#type' => 'textfield',
      '#title' => $this->t('ChatGPT API Temperature'),
      '#description' => $this->t('Please provide the Temperature value here. Please set it to 0.9 for most creative output.'),
      '#default_value' => $config->get('chatgpt_temperature'),
    ];

    $form['chatgpt_max_token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('ChatGPT API Max Token'),
      '#description' => $this->t('Please provide the ChatGPT max token or word count value here.'),
      '#default_value' => $config->get('chatgpt_max_token'),
    ];

    return parent::buildForm($form, $form_state);

  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('chatgpt.adminsettings')
      ->set('chatgpt_endpoint', $form_state->getValue('chatgpt_endpoint'))
      ->set('chatgpt_model', $form_state->getValue('chatgpt_model'))
      ->set('chatgpt_token', $form_state->getValue('chatgpt_token'))
      ->set('chatgpt_temperature', $form_state->getValue('chatgpt_temperature'))
      ->set('chatgpt_max_token', $form_state->getValue('chatgpt_max_token'))
      ->save();

  }

}

==> chatgpt_plugin-1.0.1.tar.gz: chatgpt_plugin/src/Form/ChatGPTConfigForm.php <==
<?php

namespace Drupal\chatgpt_plugin\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Function to create the ChatGPT Config Form.
 */
class ChatGPTConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'chatgpt_plugin.adminsettings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'chatgpt_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('chatgpt_plugin.adminsettings');

    $form['chatgpt_setting_compare_tool'] = [
      '#type' => 'markup',
      '#markup' => '<a id="chatgpt-tool" href="https://gpttools.com/comparisontool" target="_blank">Click here to access the ChatGPT API setting comparison tool</a>',
    ];

    $form['chatgpt_endpoint'] = [
      '#type' => 'textfield',
      '#title' => $this->t('ChatGPT API Endpoint'),
      '#description' => $this->t('Please provide the ChatGPT Completion API Endpoint here.'),
      '#default_value' => $config->get('chatgpt_endpoint') ? $config->get('chatgpt_endpoint') : 'https://api.openai.com/v1/completions',
      '#required' => TRUE,
    ];

    $form['chatgpt_model'] = [
      '#type' => 'textfield',
      '#title' => $this->t('ChatGPT API Model'),
      '#description' => $this->t('Please provide the ChatGPT API Model here. List of models can be found
                        <a href="https://beta.openai.com/docs/models/gpt-3" target="_blank"><b>Here</b></a>'),
      '#default_value' => $config->get('chatgpt_model'),
      '#required' => TRUE,
    ];

    $form['chatgpt_token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('ChatGPT Access Token'),
      '#description' => $this->t('Please provide the ChatGPT Access Token here.'),
      '#default_value' => $config->get('chatgpt_token'),
      '#required' => TRUE,
    ];

    $form['chatgpt_max_token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('ChatGPT API Max Token'),
      '#description' => $this->t('Please provide the ChatGPT max token here to limit the output words. Max token is the
                        limit <br>of tokens combining both input prompt and output text. 1 token is approx 4 chars in English.'),
      '#default_value' => $config->get('chatgpt_max_token'),
      '#required' => TRUE,
    ];

    $form['chatgpt_temperature'] = [
      '#type' => 'textfield',
      '#title' => $this->t('ChatGPT API Temperature'),
      '#description' => $this->t('Please provide the Temperature value here. Please set it to 0.9 for most creative output.'),
      '#default_value' => $config->get('chatgpt_temperature'),
    ];

    return parent::buildForm($form, $form_state);

  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('chatgpt_plugin.adminsettings')
      ->set('chatgpt_endpoint', $form_state->getValue('chatgpt_endpoint'))
      ->set('chatgpt_model', $form_state->getValue('chatgpt_model'))
      ->set('chatgpt_token', $form_state->getValue('chatgpt_token'))
      ->set('chatgpt_temperature', $form_state->getValue('chatgpt_temperature'))
      ->set('chatgpt_max_token', $form_state->getValue('chatgpt_max_token'))
      ->save();

  }

}
